@@ -578,6 +578,10 @@ extern "C" int main(int argc, char **argv)
 	if(cp && *cp)
 		priority = atoi(cp);
 
+	cp = getenv("HISTORY");
+	if(cp && *cp)
+		process::setHistory(atoi(cp));
+
 	cp = getenv("VERBOSE");
 	if(cp && *cp) {
 		warned = true;
@@ -632,6 +636,12 @@ extern "C" int main(int argc, char **argv)
 			continue;
 		} 
 
+		if(!strnicmp(*argv, "-history=", 10)) {
+			process::setHistory(atoi(*argv + 10));
+			continue;
+		} 
+
+
 		if(!stricmp(*argv, "-concurrency")) {
 			cp = *(++argv);
 			if(!cp) {
